@@ -284,9 +284,7 @@
   "?:"
   "!!"
   "is"
-  "!is"
   "in"
-  "!in"
   "as"
   "as?"
   ".."
